@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2017 Red Hat, Inc.
+ * Copyright © 2012 – 2018 Red Hat, Inc.
  * Copyright © 2009 Yorba Foundation
  *
  * This program is free software: you can redistribute it and/or modify
@@ -1080,6 +1080,32 @@ photos_utils_get_version (void)
 }
 
 
+void
+photos_utils_launch_online_accounts (const gchar *account_id)
+{
+  GApplication *app;
+  g_autoptr (GDBusActionGroup) control_center = NULL;
+  GDBusConnection *connection;
+  GVariant *parameters;
+  g_auto (GVariantBuilder) panel_parameters = G_VARIANT_BUILDER_INIT (G_VARIANT_TYPE ("av"));
+
+  app = g_application_get_default ();
+  connection = g_application_get_dbus_connection (app);
+  control_center = g_dbus_action_group_get (connection, "org.gnome.ControlCenter", "/org/gnome/ControlCenter");
+
+  if (account_id != NULL && account_id[0] != '\0')
+    {
+      GVariant *account_id_variant;
+
+      account_id_variant = g_variant_new_string (account_id);
+      g_variant_builder_add (&panel_parameters, "v", account_id_variant);
+    }
+
+  parameters = g_variant_new ("(s@av)", "online-accounts", g_variant_builder_end (&panel_parameters));
+  g_action_group_activate_action (G_ACTION_GROUP (control_center), "launch-panel", parameters);
+}
+
+
 void
 photos_utils_list_box_header_func (GtkListBoxRow *row, GtkListBoxRow *before, gpointer user_data)
 {
